@@ -85,7 +85,7 @@ service JobFileService {
     }
 }
 '''
-data = protoparser.parse(content)
-for i in data.messages:
-    message = data.messages[i]
+# data = protoparser.parse(content)
+# for i in data.messages:
+#     message = data.messages[i]
 print(protoparser.serialize2json(content))
\ No newline at end of file
